==> jscommunicator-1.0.21.tgz: package/lib/genericTransactionalSms.js <==
"use strict";

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var base = require('./base');
var types = require('./types');

var SmsGenericTransactional = function (_base$Base) {
  _inherits(SmsGenericTransactional, _base$Base);

  function SmsGenericTransactional(host, config, appName) {
    _classCallCheck(this, SmsGenericTransactional);

    return _possibleConstructorReturn(this, (SmsGenericTransactional.__proto__ || Object.getPrototypeOf(SmsGenericTransactional)).call(this, host, config, appName));
  }

  _createClass(SmsGenericTransactional, [{
    key: 'sendSms',
    value: function sendSms(referenceId, referenceType, name, to, messageType, body) {
      var notes = arguments.length > 6 && arguments[6] !== undefined ? arguments[6] : null;
      var expiryTime = arguments.length > 7 && arguments[7] !== undefined ? arguments[7] : null;
      var senderId = arguments.length > 8 && arguments[8] !== undefined ? arguments[8] : null;

      var job = new types.GenericTransactionalSms();
      job.reference_id = referenceId;
      job.reference_type = referenceType;
      job.name = name;
      job.mobile = to;
      job.app_name = this.appName;
      job.message_type = messageType.toUpperCase();
      job.message_text = body;
      job.notes = notes;
      job.expiry_time = expiryTime;
      job.sender_id = senderId;
      job.sms_type = 'generic_transactional';
      this.send(job, this.queueNames.sendGenericTransactionalSmsQueue, 0);
    }
  }, {
    key: 'getMessagesByReferenceId',
    value: function getMessagesByReferenceId(referenceId, smsTypes, callback) {
      if (!Array.isArray(smsTypes)) {
        throw "smsTypes should be array";
      }
      var data = {};
      data.reference_id = referenceId;
      data.sms_types = JSON.stringify(smsTypes);
      this.get('/generictransactionalsms/get_messages_by_reference_id', data, function (err, response) {
        if (err) {
          callback(err);
        } else {
          callback(null, response);
        }
      });
    }
  }, {
    key: 'isMessageSentOfTypeForRecipient',
    value: function isMessageSentOfTypeForRecipient(messageType, mobile, callback) {
      var data = {};
      data.message_type = messageType;
      data.mobile = mobile;
      var response = this.get('/generictransactionalsms/is_msg_sent_of_type_for_recipient', data, function (err, response) {
        if (err) {
          callback(err);
        } else {
          callback(null, response);
        }
      });
    }
  }, {
    key: 'getMessageCountByType',
    value: function getMessageCountByType(messageType, startDate, endDate, status, callback) {
      var data = {};
      data.message_type = messageType;
      data.start_date = startDate;
      data.end_date = endDate;
      data.status = status;
      var response = this.get('/generictransactionalsms/get_message_count_for_type', data, function (err, response) {
        if (err) {
          callback(err);
        } else {
          callback(null, response);
        }
      });
    }
  }, {
    key: 'getMessageCountByReferenceIds',
    value: function getMessageCountByReferenceIds(referenceIds, smsTypes, callback) {
      if (!Array.isArray(referenceIds)) {
        throw "referenceIds should be array";
      }
      if (!Array.isArray(smsTypes)) {
        throw "smsTypes should be array";
      }
      var data = {};
      data.reference_ids = JSON.stringify(referenceIds);
      data.sms_types = JSON.stringify(smsTypes);
      var response = this.get('/generictransactionalsms/get_message_count_by_reference_ids', data, function (err, response) {
        if (err) {
          callback(err);
        } else {
          callback(null, response);
        }
      });
    }
  }, {
    key: 'validateSmsType',
    value: function validateSmsType(type) {
      var allowedTypes = ['WEEKLY_ROI_SMS', 'VN_DETAILS', 'SURVEY_SMS', 'MARKETING_APP_LINK_SMS', 'VN_APP_PROMOTION_SMS', 'SURVEY_VERIFICATION_SMS', 'QIKWELL_APPOINTMENT_REMINDER_SMS', 'OTP', 'CONSULT_DOCTOR_REPLY_SMS', 'CONSULT_GENERIC_SMS', 'ORDER_SMS', 'SMS_ERROR_RESPONSE', 'GUARANTEE_CLAIM', 'FEEDBACK_NOTIFICATION_SMS', 'FIT_RAY_SHARE_SMS', 'VN_CALL_SUMMARY', 'DX_ORDER_SMS', 'FEEDBACK_STATUS_SMS', 'MAGIC_LINK_SMS', 'DX_ORDER_NOTIFICATION', 'DX_ORDER_CREATED_CUSTOMER', 'DX_ORDER_RESCHEDULE_CUSTOMER', 'DX_PHLEBO_UPDATED', 'DX_LAB_VISIT_REMAINDER', 'DX_HOME_SAMPLE_REMAINDER', 'DX_TEST_PREPARATION', 'DX_REPORT_SHARED', 'DX_ORDER_CANCELLED_EDIT_CUSTOMER', 'DX_ORDER_CANCELLED_CUSTOMER', 'PHR_INVITE_SMS', 'PHR_RECORD_SHARED_SMS', 'PHR_DAILY_UNCLAIMED_REMINDER_SMS', 'PHR_DAILY_UNVIEWED_REMINDER_SMS', 'PHR_UNCLAIMED_RECORDS_EXPIRY_REMINDER', 'PHR_PAYMENT_TRANSACTION_INVITE_SMS', 'PHR_TAX_SAVING_NOTIFICATION_SMS', 'SOS'];

      if (allowedTypes.indexOf(type) < 0) {
        throw "Invalid mail type";
      }
    }
  }]);

  return SmsGenericTransactional;
}(base.Base);

module.exports = {
  SmsGenericTransactional: SmsGenericTransactional
};

==> jscommunicator-1.0.26.tgz: package/lib/genericTransactionalSms.js <==
"use strict";

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var base = require('./base');
var types = require('./types');

var SmsGenericTransactional = function (_base$Base) {
  _inherits(SmsGenericTransactional, _base$Base);

  function SmsGenericTransactional(host, config, appName) {
    _classCallCheck(this, SmsGenericTransactional);

    return _possibleConstructorReturn(this, (SmsGenericTransactional.__proto__ || Object.getPrototypeOf(SmsGenericTransactional)).call(this, host, config, appName));
  }

  _createClass(SmsGenericTransactional, [{
    key: 'sendSms',
    value: function sendSms(referenceId, referenceType, name, to, messageType, body) {
      var notes = arguments.length > 6 && arguments[6] !== undefined ? arguments[6] : null;
      var expiryTime = arguments.length > 7 && arguments[7] !== undefined ? arguments[7] : null;
      var senderId = arguments.length > 8 && arguments[8] !== undefined ? arguments[8] : null;

      var job = new types.GenericTransactionalSms();
      job.reference_id = referenceId;
      job.reference_type = referenceType;
      job.name = name;
      job.mobile = to;
      job.app_name = this.appName;
      job.message_type = messageType.toUpperCase();
      job.message_text = body;
      job.notes = notes;
      job.expiry_time = expiryTime;
      job.sender_id = senderId;
      job.sms_type = 'generic_transactional';
      this.send(job, this.queueNames.sendGenericTransactionalSmsQueue, 0);
    }
  }, {
    key: 'getMessagesByReferenceId',
    value: function getMessagesByReferenceId(referenceId, smsTypes, callback) {
      if (!Array.isArray(smsTypes)) {
        throw "smsTypes should be array";
      }
      var data = {};
      data.reference_id = referenceId;
      data.sms_types = JSON.stringify(smsTypes);
      this.get('/generictransactionalsms/get_messages_by_reference_id', data, function (err, response) {
        if (err) {
          callback(err);
        } else {
          callback(null, response);
        }
      });
    }
  }, {
    key: 'isMessageSentOfTypeForRecipient',
    value: function isMessageSentOfTypeForRecipient(messageType, mobile, callback) {
      var data = {};
      data.message_type = messageType;
      data.mobile = mobile;
      var response = this.get('/generictransactionalsms/is_msg_sent_of_type_for_recipient', data, function (err, response) {
        if (err) {
          callback(err);
        } else {
          callback(null, response);
        }
      });
    }
  }, {
    key: 'getMessageCountByType',
    value: function getMessageCountByType(messageType, startDate, endDate, status, callback) {
      var data = {};
      data.message_type = messageType;
      data.start_date = startDate;
      data.end_date = endDate;
      data.status = status;
      var response = this.get('/generictransactionalsms/get_message_count_for_type', data, function (err, response) {
        if (err) {
          callback(err);
        } else {
          callback(null, response);
        }
      });
    }
  }, {
    key: 'getMessageCountByReferenceIds',
    value: function getMessageCountByReferenceIds(referenceIds, smsTypes, callback) {
      if (!Array.isArray(referenceIds)) {
        throw "referenceIds should be array";
      }
      if (!Array.isArray(smsTypes)) {
        throw "smsTypes should be array";
      }
      var data = {};
      data.reference_ids = JSON.stringify(referenceIds);
      data.sms_types = JSON.stringify(smsTypes);
      var response = this.get('/generictransactionalsms/get_message_count_by_reference_ids', data, function (err, response) {
        if (err) {
          callback(err);
        } else {
          callback(null, response);
        }
      });
    }
  }, {
    key: 'validateSmsType',
    value: function validateSmsType(type) {
      var allowedTypes = ['WEEKLY_ROI_SMS', 'VN_DETAILS', 'SURVEY_SMS', 'MARKETING_APP_LINK_SMS', 'VN_APP_PROMOTION_SMS', 'SURVEY_VERIFICATION_SMS', 'QIKWELL_APPOINTMENT_REMINDER_SMS', 'OTP', 'CONSULT_DOCTOR_REPLY_SMS', 'CONSULT_GENERIC_SMS', 'CONSULT_SMS_MAGIC_LINK', 'ORDER_SMS', 'SMS_ERROR_RESPONSE', 'GUARANTEE_CLAIM', 'FEEDBACK_NOTIFICATION_SMS', 'FIT_RAY_SHARE_SMS', 'VN_CALL_SUMMARY', 'DX_ORDER_SMS', 'FEEDBACK_STATUS_SMS', 'MAGIC_LINK_SMS', 'DX_ORDER_NOTIFICATION', 'DX_ORDER_CREATED_CUSTOMER', 'DX_ORDER_RESCHEDULE_CUSTOMER', 'DX_PHLEBO_UPDATED', 'DX_LAB_VISIT_REMAINDER', 'DX_HOME_SAMPLE_REMAINDER', 'DX_TEST_PREPARATION', 'DX_REPORT_SHARED', 'DX_ORDER_CANCELLED_EDIT_CUSTOMER', 'DX_ORDER_CANCELLED_CUSTOMER', 'PHR_INVITE_SMS', 'PHR_RECORD_SHARED_SMS', 'PHR_DAILY_UNCLAIMED_REMINDER_SMS', 'PHR_DAILY_UNVIEWED_REMINDER_SMS', 'PHR_UNCLAIMED_RECORDS_EXPIRY_REMINDER', 'PHR_PAYMENT_TRANSACTION_INVITE_SMS', 'PHR_TAX_SAVING_NOTIFICATION_SMS', 'SOS'];

      if (allowedTypes.indexOf(type) < 0) {
        throw "Invalid mail type";
      }
    }
  }]);

  return SmsGenericTransactional;
}(base.Base);

module.exports = {
  SmsGenericTransactional: SmsGenericTransactional
};
